@@ -1,6 +1,5 @@
 import errno
 import os
-from tempfile import NamedTemporaryFile
 
 
 def mkdir_p(path):
@@ -37,15 +36,13 @@ def recreate_symlinks(symlinks, destination_path):
         os.symlink(symlink["destination"], link_path)
 
 
-def create_temp_file(content):
-    cert = NamedTemporaryFile(delete=False)
-    content = content if type(content) is bytes else content.encode()
-    cert.write(content)
-    cert.close()
-    return cert
+def get_topic_folder(settings):
+    topic_name = settings["name"].strip().replace(" ", "_")
+    download_folder = settings["download_folder"]
+    return os.path.join(download_folder, topic_name)
 
 
-def build_download_folder(topic, component, download_folder):
-    topic_name = topic["name"].strip().replace(" ", "_")
+def get_component_folder(settings, component):
+    topic_folder = get_topic_folder(settings)
     component_type = component["type"].strip().replace(" ", "_").lower()
-    return os.path.join(download_folder, topic_name, component_type)
+    return os.path.join(topic_folder, component_type)
